boxholder

package
v0.0.0-...-145f379 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2023 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BoxholderData

type BoxholderData struct {

	//these should be number delivered (ie 350 boxes got a bh on a given day)
	BoxholderFlats   int
	BoxholderLetters int
}

BoxholderData contains all the info for calculating boxholder time

func (*BoxholderData) GetTime

func (bhd *BoxholderData) GetTime() float64

func (*BoxholderData) Populate

func (bhd *BoxholderData) Populate(dd ds.DailyData, fd ds.FixedData)

func (*BoxholderData) Report

func (bhd *BoxholderData) Report() string

func (*BoxholderData) TotalBoxholders

func (bhd *BoxholderData) TotalBoxholders() int

The total number of boxholders recieved for the route

Jump to