flat

package
v0.0.0-...-145f379 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2023 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CaseDPSFlats

func CaseDPSFlats(dd ds.DailyData, fd ds.FixedData) bool

CaseDPSFlats checks if a route is paid to case their DPSflats or not.

Types

type FlatData

type FlatData struct {
	RandomFlats       int
	CarrierRouteFlats int
	WSSFlats          int

	DPSFlats int

	// Do you drive a personally owned vehicle or left hand drive gov machine?
	DrivePOV   bool
	DriveGOVLH bool
}

FlatData contains all the info for calculating flat times

func (*FlatData) CasedFlats

func (fd *FlatData) CasedFlats() int

The total number of flats paid to case

func (*FlatData) GetTime

func (fd *FlatData) GetTime() float64

func (*FlatData) Populate

func (f *FlatData) Populate(dd ds.DailyData, fd ds.FixedData)

func (*FlatData) Report

func (fd *FlatData) Report() string

func (*FlatData) TotalFlats

func (fd *FlatData) TotalFlats() int

The total number of flats recieved for the route

Jump to