fullRRECS

package
v0.0.0-...-145f379 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2023 License: GPL-3.0 Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateReport

func GenerateReport(fd dataSets.FixedData, dd dataSets.DailyData) string

GenearteReport returns a detailed report for a set of fixed and daily data

func GetTime

GetTime returns daily eval for a set of fixed and daily data

Types

This section is empty.

Jump to