reload

package
v0.0.0-...-145f379 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2023 License: GPL-3.0 Imports: 4 Imported by: 0

README

Reload Tables

The tables, as presented in the comprehensive guide:

  1. Do not seem to be based off of the numbers from the 4241-M
  2. Do not contain enough entries

The program in table gen will extrapolate out the table for more entries. It uses the same numbers from the table (see the excel file in the folder) even though they are suspect.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ReloadData

type ReloadData struct {

	//cased letters
	RandomLetters    int
	WSSLetters       int
	BoxholderLetters int
	CasedDPSLetters  int

	//cased flats
	RandomFlats    int
	CRFlats        int
	WSSFlats       int
	BoxholderFlats int

	//DPS
	DPSLetters int
	DPSFlats   int

	//parcels
	MailBoxParcels int
	LockerParcels  int
	DoorParcels    int

	Bundle standards.Bundling
}

func (*ReloadData) GetLargeParcelTime

func (rd *ReloadData) GetLargeParcelTime() float64

func (*ReloadData) GetMailTrayTime

func (rd *ReloadData) GetMailTrayTime() float64

TODO: does not consider DPS letters < 400. impact on time minimal, not worth the code

func (*ReloadData) GetMediumParcelTime

func (rd *ReloadData) GetMediumParcelTime() float64

func (*ReloadData) GetTime

func (rd *ReloadData) GetTime() float64

func (*ReloadData) Populate

func (rd *ReloadData) Populate(dd ds.DailyData, fd ds.FixedData)

func (*ReloadData) Report

func (rd *ReloadData) Report() string

Directories

Path Synopsis

Jump to