Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BoxholderData ¶
type BoxholderData struct {
//these should be number delivered (ie 350 boxes got a bh on a given day)
BoxholderFlats int
BoxholderLetters int
}
BoxholderData contains all the info for calculating boxholder time
func (*BoxholderData) GetTime ¶
func (bhd *BoxholderData) GetTime() float64
func (*BoxholderData) Populate ¶
func (bhd *BoxholderData) Populate(dd ds.DailyData, fd ds.FixedData)
func (*BoxholderData) Report ¶
func (bhd *BoxholderData) Report() string
func (*BoxholderData) TotalBoxholders ¶
func (bhd *BoxholderData) TotalBoxholders() int
The total number of boxholders recieved for the route
Click to show internal directories.
Click to hide internal directories.