Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type FlatData ¶
type FlatData struct {
RandomFlats int
CarrierRouteFlats int
WSSFlats int
DPSFlats int
// Do you drive a personally owned vehicle or left hand drive gov machine?
DrivePOV bool
DriveGOVLH bool
}
FlatData contains all the info for calculating flat times
func (*FlatData) CasedFlats ¶
The total number of flats paid to case
func (*FlatData) TotalFlats ¶
The total number of flats recieved for the route
Click to show internal directories.
Click to hide internal directories.